@@ -101,8 +101,19 @@ def test_cmap_combo(qtbot, filterable):
         return  # the rest fails on CI... but works locally
 
     # click the Add Colormap... item
+    # NOTE: We wrap __init__ instead of patching exec directly because
+    # PySide6 6.10 crashes when MetaObjectBuilder inspects mocked methods
+    # during signal connection (parsePythonType segfault)
+    _original_init = _cmap_combo._CmapNameDialog.__init__
+
+    def _init_with_mock_exec(self, *args, **kwargs):
+        _original_init(self, *args, **kwargs)
+        self.exec = lambda: True
+
     with qtbot.waitSignal(wdg.currentColormapChanged):
-        with patch.object(_cmap_combo._CmapNameDialog, "exec", return_value=True):
+        with patch.object(
+            _cmap_combo._CmapNameDialog, "__init__", _init_with_mock_exec
+        ):
             wdg._on_activated(wdg.count() - 1)
 
     assert wdg.count() == 5
@@ -111,7 +122,13 @@ def test_cmap_combo(qtbot, filterable):
     assert wdg.itemColormap(3).name.split(":")[-1] == "accent"
 
     # click the Add Colormap... item, but cancel the dialog
-    with patch.object(_cmap_combo._CmapNameDialog, "exec", return_value=False):
+    def _init_with_mock_exec_false(self, *args, **kwargs):
+        _original_init(self, *args, **kwargs)
+        self.exec = lambda: False
+
+    with patch.object(
+        _cmap_combo._CmapNameDialog, "__init__", _init_with_mock_exec_false
+    ):
         wdg._on_activated(wdg.count() - 1)
 
 
